@@ -2,16 +2,20 @@
 #
 # This file is part of pyasn1-modules software.
 #
-# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
-# License: http://pyasn1.sf.net/license.html
+# Copyright (c) 2005-2019, Ilya Etingof <etingof@gmail.com>
+# License: http://snmplabs.com/pyasn1/license.html
 #
 # Read ASN.1/PEM X.509 certificate requests (PKCS#10 format) on stdin, 
 # parse each into plain text, then build substrate from it
 #
-from pyasn1.codec.der import decoder, encoder
-from pyasn1_modules import rfc2314, pem
 import sys
 
+from pyasn1.codec.der import decoder
+from pyasn1.codec.der import encoder
+
+from pyasn1_modules import pem
+from pyasn1_modules import rfc2314
+
 if len(sys.argv) != 1:
     print("""Usage:
 $ cat certificateRequest.pem | %s""" % sys.argv[0])
