@@ -2,16 +2,20 @@
 #
 # This file is part of pyasn1-modules software.
 #
-# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
-# License: http://pyasn1.sf.net/license.html
+# Copyright (c) 2005-2019, Ilya Etingof <etingof@gmail.com>
+# License: http://snmplabs.com/pyasn1/license.html
 #
 # Read ASN.1/PEM PKCS#7 on stdin, parse it into plain text,
 # then build substrate from it
 #
-from pyasn1_modules import rfc2315, pem
-from pyasn1.codec.der import encoder, decoder
 import sys
 
+from pyasn1.codec.der import decoder
+from pyasn1.codec.der import encoder
+
+from pyasn1_modules import pem
+from pyasn1_modules import rfc2315
+
 if len(sys.argv) != 1:
     print("""Usage:
 $ cat pkcs7Certificate.pem | %s""" % sys.argv[0])
