@@ -2,15 +2,18 @@
 #
 # This file is part of pyasn1-modules software.
 #
-# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
-# License: http://pyasn1.sf.net/license.html
+# Copyright (c) 2005-2019, Ilya Etingof <etingof@gmail.com>
+# License: http://snmplabs.com/pyasn1/license.html
 #
 # Generate SNMPGET request, parse response
 #
-from pyasn1.codec.ber import encoder, decoder
-from pyasn1_modules import rfc1157
-import sys
 import socket
+import sys
+
+from pyasn1.codec.ber import decoder
+from pyasn1.codec.ber import encoder
+
+from pyasn1_modules import rfc1157
 
 if len(sys.argv) != 4:
     print("""Usage:
